@@ -5,7 +5,7 @@ from .get_live_status import GetLiveStatus
 from .send_live import SendLive
 
 
-class Messages(
+class Lives(
     AddLiveComment,
     GetLiveComments,
     GetLiveStatus,
