@@ -36,7 +36,7 @@ class AddLiveComment:
         Returns:
             rubigram.types.Update: The update response confirming the comment was added.
         """
-        return await self.client.builder(
+        return await self.builder(
             'addLiveComment',
             input={
                 'live_id': live_id,
