@@ -12,6 +12,7 @@ class SendMusic:
         caption: Optional[str] = None,
         reply_to_message_id: Optional[str] = None,
         auto_delete: Optional[int] = None,
+        progress: bool = False,
         *args, **kwargs,
     ) -> rubigram.types.Update:
         """
@@ -40,5 +41,6 @@ class SendMusic:
             file_inline=music,
             type='Music',
             auto_delete=auto_delete,
+            progress=progress,
             *args, **kwargs
         )
