@@ -12,7 +12,8 @@ class SendVideoMessage:
             video_message: Union[Path, bytes],
             caption: Optional[str] = None,
             reply_to_message_id: Optional[str] = None,
-            auto_delete: Optional[int] = None, *args, **kwargs,
+            auto_delete: Optional[int] = None,
+            progress: bool = False, *args, **kwargs,
     ) -> "rubigram.types.Update":
         """
         Send a video message.
@@ -41,5 +42,6 @@ class SendVideoMessage:
             file_inline=video_message,
             type='VideoMessage',
             auto_delete=auto_delete,
+            progress=progress,
             *args, **kwargs
         )
