@@ -84,7 +84,7 @@ class Update:
         return self.find_keys('message')
 
     @property
-    def me(self):
+    def is_me(self):
         return self.author_guid == self.client.guid
 
     @property
@@ -109,7 +109,7 @@ class Update:
         return self.find_keys('title')
 
     @property
-    def forward(self) -> bool:
+    def is_forward(self) -> bool:
         message = self.message
         return message is not None and 'forwarded_from' in message.original_update
 
@@ -156,7 +156,7 @@ class Update:
         return self.file_inline is not None and self.file_inline.type == 'Voice'
 
     @property
-    def contact(self):
+    def is_in_contact(self):
         return self.file_inline is not None and self.file_inline.type == 'Contact'
 
     @property
@@ -188,15 +188,15 @@ class Update:
         return self.message.find_keys(keys='reply_to_message_id')
 
     @property
-    def group(self):
+    def is_group(self):
         return self.type == 'Group'
 
     @property
-    def channel(self):
+    def is_channel(self):
         return self.type == 'Channel'
 
     @property
-    def private(self):
+    def is_private(self):
         return self.type == 'User'
 
     @property
